# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Test-CPAN-Meta
Version:	0.25
Release:	33.%{__distinit}%{__distvers}
Summary:	Validation of the META.yml file in a CPAN distribution
License:	Artistic-2.0
URL:		https://metacpan.org/release/Test-CPAN-Meta
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-CPAN-Meta-%{version}.tar.gz
Patch0:		Test-CPAN-Meta-0.25-utf8.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Parse::CPAN::Meta) >= 0.02
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(IO::File)
BuildRequires:	perl(Test::Builder::Tester)
BuildRequires:	perl(Test::More) >= 0.62
# Optional Tests
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(Test::CPAN::Meta::JSON)
%endif
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage) >= 0.08
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
This module was written to ensure that a META.yml file, provided with a
standard distribution uploaded to CPAN, meets the specifications that are
slowly being introduced to module uploads, via the use of package makers
and installers such as ExtUtils::MakeMaker, Module::Build and
Module::Install.

%prep
%setup -q -n Test-CPAN-Meta-%{version}

# Re-code documentation as UTF-8
%patch -P 0

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test AUTOMATED_TESTING=1

%files
%license LICENSE
%doc Changes README examples/
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::CPAN::Meta.3*
%{_mandir}/man3/Test::CPAN::Meta::Version.3*

%changelog
* Wed Jul 12 2023 Paul Howarth <paul@city-fan.org> - 0.25-33
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax
- Use %%license unconditionally

* Mon Jun  3 2019 Paul Howarth <paul@city-fan.org> - 0.25-18
- Perl 5.30 rebuild

* Wed Apr 11 2018 Paul Howarth <paul@city-fan.org> - 0.25-12
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Thu Sep 29 2016 Paul Howarth <paul@city-fan.org> - 0.25-7
- BR: perl-generators where available
- Simplify find command using -delete

* Sun Jun 21 2015 Paul Howarth <paul@city-fan.org> - 0.25-4
- Perl 5.22 rebuild

* Wed May  6 2015 Paul Howarth <paul@city-fan.org> - 0.25-1
- Update to 0.25
  - POD fix for usage example
  - Removed Test::CPAN::Meta from the recommends list, as CPAN.pm tries to
    install it first (CPAN RT#104023)
- Update UTF8 patch

* Tue Mar 17 2015 Paul Howarth <paul@city-fan.org> - 0.24-2
- Don't BR: perl(Test::CPAN::Meta::JSON) when bootstrapping

* Tue Jan 13 2015 Paul Howarth <paul@city-fan.org> - 0.24-1
- Update to 0.24
  - Extended META test suite
  - Added META.json and tests
  - Documentation updates
- Classify buildreqs by usage
- Update UTF8 patch

* Sun Aug 31 2014 Paul Howarth <paul@city-fan.org> - 0.23-5
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Wed Jul 17 2013 Paul Howarth <paul@city-fan.org> - 0.23-2
- Perl 5.18 rebuild

* Mon Apr  8 2013 Paul Howarth <paul@city-fan.org> - 0.23-1
- Update to 0.23
  - Changes file dates changed to meet W3CDTF standards
- Update UTF8 patch

* Tue Aug 21 2012 Paul Howarth <paul@city-fan.org> - 0.22-1
- Update to 0.22
  - Updated INSTALL instructions
  - Added minimum perl version (5.006)
  - Reworked Makefile.PL for clarity
  - Implemented Perl::Critic suggestions
  - Added meta_yaml_ok test and example
  - Several Version.pm updates, including new() parameter name change:
    'yaml' is now 'data'
- Update UTF8 patch

* Sat Jun 30 2012 Paul Howarth <paul@city-fan.org> - 0.21-2
- BR: perl(IO::File)

* Thu Apr 19 2012 Paul Howarth <paul@city-fan.org> - 0.21-1
- Update to 0.21
  - CPAN RT#76609: further spelling fix
  - Removed DSLIP info

* Tue Apr 17 2012 Paul Howarth <paul@city-fan.org> - 0.20-1
- Update to 0.20
  - CPAN RT#76609: Spelling fix

* Sun Apr 15 2012 Paul Howarth <paul@city-fan.org> - 0.19-1
- Update to 0.19
  - CPAN RT#74317: Imported url validation from CPAN::Meta
  - CPAN RT#66692: updated license type
  - Updates to examples
- Updated License to Artistic 2.0
- Don't need to remove empty directories from buildroot
- Use a patch rather than scripted iconv to fix character encoding
- Drop compatibility with old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use %%{_fixperms} macro rather than our own chmod incantation
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Thu Jun 30 2011 Paul Howarth <paul@city-fan.org> - 0.18-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Feb 15 2011 Paul Howarth <paul@city-fan.org> - 0.18-1
- Update to 0.18 (documentation clean up)

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 0.17-3
- Rebuild for perl 5.12.1 in Rawhide

* Wed May 12 2010 Paul Howarth <paul@city-fan.org> - 0.17-2
- Fix dist tag for RHEL-6 Beta

* Tue Apr 13 2010 Paul Howarth <paul@city-fan.org> - 0.17-1
- Update to 0.17
  - Fixed qr// delimiters due to issues with the NOT SIGN symbol

* Mon Dec 21 2009 Paul Howarth <paul@city-fan.org> - 0.16-1
- Update to 0.16
  - Renamed word() to keyword()
  - Added identifier() validation
  - Changed optional_features key from a keyword to an identifier type
  - Clarified spec defined and user defined keys

* Tue Dec  8 2009 Paul Howarth <paul@city-fan.org> - 0.14-1
- Update to 0.14
- * Fix RT#46473: license url with fragment part
- * Fix RT#47393: "optional_features" as map rather than list
- Dist tag for Rawhide no longer needs special-casing

* Tue May 26 2009 Paul Howarth <paul@city-fan.org> - 0.13-1
- Update to 0.13
- * added version checking to standard 94metatest.t
- * added changes file checking, 95changedate.t
- * added support for v-strings
- * relaxed resource keys names, as per spec
- Update to SLES-compatible dist tag macros

* Tue Nov 11 2008 Paul Howarth <paul@city-fan.org> - 0.12-2
- Import from Fedora
- Drop Test::More version requirement to support builds on old distributions

* Tue Jul 01 2008 Steven Pritchard <steve@kspei.com> - 0.12-1
- Update to 0.12
- BR Test::Builder and Test::Builder::Tester

* Wed Jun 04 2008 Steven Pritchard <steve@kspei.com> - 0.11-1
- Update to 0.11

* Fri May 16 2008 Steven Pritchard <steve@kspei.com> - 0.10-1
- Specfile autogenerated by cpanspec 1.75
- Enable author tests
- Add examples to docs
- BR Test::More
- Convert LICENSE to UTF-8
- Drop bogus Requires
